/**
 * Define locale message resource.
 * @function apemanlocale
 * @param {string} [dirname="locales"] - Directory path which contains locale messages.
 * @param {object} [options] - Optional settings.
 * @param {object} [options.default='en'] - Default lang.
 * @param {boolean} [options.fallback] - Use default lang as fallback
 * @param {boolean} [options.buildin] - Use buildin langs
 * @returns {object} - Locales
 */

'use strict';

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var _print = require('./print');
var _validate = require('./validate');
var fromFiles = require('./localing/from_files');
var sortLangs = require('./localing/sort_langs');
var registerFallback = require('./localing/register_fallback');

var _require = require('locale');

var Locales = _require.Locales;

/** @lends apemanlocale */

function apemanlocale() {
  var dirname = arguments.length <= 0 || arguments[0] === undefined ? 'locales' : arguments[0];
  var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  var defaultLang = options.default || 'en';
  var buildin = options.buildin ? require('./buildin') : {};

  var datasource = fromFiles(dirname, buildin);

  if (options.fallback) {
    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = Object.keys(datasource)[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var lang = _step.value;

        if (lang !== defaultLang) {
          registerFallback(datasource[lang], datasource[defaultLang]);
        }
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator.return) {
          _iterator.return();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }
  }

  var langs = sortLangs(Object.keys(datasource));
  var supported = new Locales(langs);

  /**
   * Locale object.
   * @param {string} lang - Lang to resolve.
   * @returns {object} - Locale object for a lang.
   */
  function locales(lang) {
    var best = new Locales(lang).best(supported);
    return datasource[best];
  }

  // noinspection Eslint
  locales.__proto__ = Object.assign(new Function(''), {
    src: dirname,
    defaultLang: defaultLang,
    langs: langs,
    print: function print() {
      _print(locales);
      return locales;
    },
    validate: function validate() {
      _validate(locales);
      return locales;
    },
    toJSON: function toJSON() {
      return langs.reduce(function (result, lang) {
        return Object.assign(result, _defineProperty({}, lang, locales(lang).toJSON()));
      }, {});
    }
  });
  Object.assign(locales, datasource);

  return locales;
}

module.exports = apemanlocale;
//# sourceMappingURL=data:application/json;base64,bnVsbA==